local player = {}

function player:init()
	self.x = windowWidth/2
	self.y = windowHeight - 100
	self.width = 50
	self.height = 100

	self.jumps = 1
	self.jumping = false
	self.onPlatform = false

	self.body = love.physics.newBody(world, self.x, self.y, "dynamic")
	self.shape = love.physics.newRectangleShape(50, 100)
	self.fixture = love.physics.newFixture(self.body, self.shape)
	self.fixture:setUserData("Player")
	self.body:setFixedRotation(true)
end

function player:update()
	self.velX, self.velY = self.body:getLinearVelocity()

	if love.keyboard.isDown("left") and math.abs(self.velX) < 500 then
		self.body:setLinearVelocity(-400, self.velY)
	elseif love.keyboard.isDown("right") and math.abs(self.velX) < 500 then
		self.body:setLinearVelocity(400, self.velY)
	else
		self.body:setLinearVelocity(0, self.velY)
	end

	if love.keyboard.isDown("up") and self.jumps > 0 and self.velY == 0 then
		self.body:applyLinearImpulse(0, -750)
		self.jumps = 0
		self.jumping = true
	end

	self.jumping = self.velY < 0

	if self.velY > 0 then
		self.body:applyLinearImpulse(0, 25)
	end

	if self.onPlatform then
	 	self.platform:setSensor(false)
    elseif not self.onPlatform and self.platform ~= nil then
    	self.platform:setSensor(true)
    end
end

function player:draw()
	love.graphics.setColor(1, 1, 1)
	love.graphics.polygon("fill", self.body:getWorldPoints(self.shape:getPoints()))
end

function player:beginContact(a, b, contact)
    function collides(data)
        return a:getUserData() == "Player" and b:getUserData() == data or a:getUserData() == data and b:getUserData() == "Player"
    end

    if collides("Floor") then
        self.jumps = 1
    end

    if collides("Platform") then
        local px, py = self.body:getPosition()
        local fx, fy = a:getBody():getPosition()

        -- Check if player is above the platform and going downwards
        if py + self.height / 2 < fy - 5 then
            self.platform = a
            self.onPlatform = true
            self.jumps = 1
        end
    end
end

function player:endContact(a, b, contact)
    function collides(data)
        return a:getUserData() == "Player" and b:getUserData() == data or a:getUserData() == data and b:getUserData() == "Player"
    end

    if collides("Platform") then
        self.onPlatform = false
    end
end


return player